<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>נקה</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>ניחוש</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>נמצאו</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>רגיל</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>גדול</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>לא נמצאו</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>זמנך עבר</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 מתוך %n נקודות</numerusform>
            <numerusform>%1 מתוך %n נקודות</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 מתוך %n נקודות</numerusform>
            <numerusform>3 מתוך %n נקודות</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 מתוך %n נקודות</numerusform>
            <numerusform>2 מתוך %n נקודות</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>נקודה 1 מתוך %n</numerusform>
            <numerusform>נקודה 1 מתוך %n</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 מתוך %n נקודות</numerusform>
            <numerusform>0 מתוך %n נקודות</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>נקודה %n</numerusform>
            <numerusform>%n נקודות</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>הניקוד המקסימלי חושב על פי שלושים המילים הבאות</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>ניחוש %n</numerusform>
            <numerusform>%n ניחושים</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>שגיאה %n</numerusform>
            <numerusform>%n שגיאות</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>טנגלט</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>קלאסי</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>מילוי</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>שלוש טעויות</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>30 נחושים</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>משמעת</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>ספירה לאחור במשך 30 שניות, והוספת זמן בניחושים נכונים</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>ספירה לאחור במשך 3 דקות</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>ספירה לאחור במשך 30 שניות, ומילוי מחדש בכל ניחוש נכון</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>ספירה לאחור במשך 45 שניות, ועצירה בכל ניחוש נכון</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>המשחק מסתיים לאחר 3 ניחושים שגויים</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>המשחק מסתיים לאחר 30 ניחושים</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>ספירה לאחור במשך 30 שניות, הוספת זמן בניחוש נכון והפחתת זמן בניחוש שגוי</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>אין אפשרות לקרוא את נתוני הקוביה מהקובץ</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>אין אפשרות לקרוא את רשימת המילים מהקובץ</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>שפת הלוח</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>מותאם אישית</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>בחר...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;הערה :&lt;/b&gt; הגדרות אלה יחולו בהתחלת משחק חדש</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>שפה:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>קוביה:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>רשימת מילים:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>מילון:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>בחר קובץ קוביה</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>בחר קובץ רשימת מילים</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת ממשק</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>שפת מערכת</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא אתחל את היישום כדי להחיל את שינוי הגדרות השפה</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>מספר מילים:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>אורך מילה מינימלי:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>נמוך</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>בינוני</translation>
    </message>
    <message>
        <source>High</source>
        <translation>גבוה</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>אקראי</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>אות %n</numerusform>
            <numerusform>%n אותיות</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>טבלת שיאים</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name&lt;/b&gt;</source>
        <translation>&lt;b&gt;שם&lt;b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Score&lt;/b&gt;</source>
        <translation>&lt;b&gt;ניקוד&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Date&lt;/b&gt;</source>
        <translation>&lt;b&gt;תאריך&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
        <translation>&lt;b&gt;סוג משחק&lt;/b&gt;</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>מס&apos; %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Clear high scores?</source>
        <translation>למחוק שיאים שמורים?</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>טנגלט</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;מושהה&lt;/big&gt;&lt;/b&gt;&lt;br&gt;לחץ להמשך המשחק&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&quot;&lt;p&gt;&lt;b&gt;&lt;big&gt;אנא המתן&lt;/big&gt;&lt;/b&gt;&lt;br&gt;טוען משחק...&lt;/p&gt;&quot;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>לחץ להתחלת משחק חדש</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;אנא המתן&lt;/big&gt;&lt;/b&gt;&lt;br&gt;בונה לוח חדש...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;אנא המתן&lt;/big&gt;&lt;/b&gt;&lt;br&gt;מטייב את רשימת המלים...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>משחק חדש...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>איפוס משחק נוכחי</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>יבוא משחק...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>יצוא משחק...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>סיום</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>טבלת שיאים</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>הצגת ניקוד מקסימלי</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>לעולם לא</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>בסוף המשחק</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>תמיד</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>הצג מילים שלא נמצאו</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>הצג ספירת מילים</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>שפת הלוח...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>שפת ממשק...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>הוראות</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>About &amp;Hspell</source>
        <translation>אודות &amp;Hspell</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;SCOWL</source>
        <translation>אודות &amp;SCOWL</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>טנגלט %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>גרסה לשחקן בודד של &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>מופץ בכפוף לרשיון &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>רשימת המילים בעברית מבוססת על &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; שנכתב ע&quot;י נדב הראל ודן קניגסברג</translation>
    </message>
    <message>
        <source>About Hspell</source>
        <translation>אודות Hspell</translation>
    </message>
    <message>
        <source>About SCOWL</source>
        <translation>אודות SCOWL</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>יבוא משחק</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>משחקי טנגלט (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>אין אפשרות להתחיל את המשחק המבוקש</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>יצוא משחק</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>לסיים את המשחק הנוכחי?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>גודל הלוח:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>רגיל</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>גדול</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>צפיפות מילים:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>אורך מילה:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 אותיות או יותר</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>סוג משחק:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>תאור:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>הוראות</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;שימוש בעכבר:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;בחר מילה:&lt;/b&gt; לחץ על אותיות של מילה&lt;br&gt;&lt;b&gt;הצע מילה:&lt;/b&gt; לחץ על האות האחרונה שנבחרה&lt;br&gt;&lt;b&gt;מחק אותיות:&lt;/b&gt; לחץ על אות שנבחרה קודם&lt;br&gt;&lt;b&gt;מחק את המילה:&lt;/b&gt; לחץ פעמיים על האות הראשונה שנבחרה&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;שימוש במקלדת:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;בחר מילה:&lt;/b&gt; הקלד אותיות של מילה&lt;br&gt;&lt;b&gt;הצע מילה:&lt;/b&gt; לחץ Enter&lt;br&gt;&lt;b&gt;מחק את המילה:&lt;/b&gt; לחץ Ctrl+Backspace&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>אותיות:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>נמצאו:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>נקודה %n</numerusform>
            <numerusform>%n נקודות</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
